@@ -950,6 +950,12 @@ void map_draw_terrain( SDL_Surface *surf, int map_x, int map_y, int x, int y )
         SOURCE( terrain_icons->grid, 0, 0 );
         blit_surf();
     }
+    /* escape zone? do danger mask overlay with less transparency */
+    if (tile->escape_zone) {
+		DEST( surf, x, y, hex_w, hex_h );
+		SOURCE( terrain_icons->danger, 0, 0);
+		alpha_blit_surf(DANGER_ALPHA/2);
+	}
 }
 /*
 ====================================================================
@@ -1583,6 +1589,13 @@ is given, check whether it is any
 */
 static int map_check_deploy_center( Player *player, Unit *unit, int mx, int my )
 {
+    //that part allows planes to spawn from an aircraft carrier
+    if( unit )
+	if(unit->sel_prop->flags&FLYING)
+		if( map_tile(mx,my)->g_unit )
+			if( (map_tile(mx,my)->g_unit->sel_prop->flags & CARRIER) )
+				if( player_is_ally( map_tile(mx,my)->g_unit->player, unit->player ) )
+					return 1;
     if (map[mx][my].deploy_center!=1||!map[mx][my].player) return 0;
     if (!player_is_ally(map[mx][my].player,player)) return 0;
     if (unit)
@@ -1706,8 +1719,13 @@ void map_get_deploy_mask( Player *player, Unit *unit, int init )
                 {
                     if (map[x][y].a_unit) mask[x][y].deploy = 0;
                 } else {
-                    if (map[x][y].g_unit&&(!init||!map_check_unit_embark(unit,x,y,EMBARK_AIR,1))) 
-                        mask[x][y].deploy = 0;
+                	/* blocked by unit and we are not embarkable? */
+                	if (map[x][y].g_unit&&(!init||!map_check_unit_embark(unit,x,y,EMBARK_AIR,1)))
+                		mask[x][y].deploy = 0;
+                	/* can we move on tile? (don't go into ocean...)
+                	 * unless initial deploy */
+                	if (!init && terrain_get_mov(map[x][y].terrain,unit->prop.mov_type,cur_weather) == 0)
+                		mask[x][y].deploy = 0;
                 }
     }
 }
