@@ -90,6 +90,8 @@ char scen_message[128] = ""; /* the final scenario message is saved here */
 int vcond_check_type = 0;   /* test victory conditions this turn */
 VCond *vconds = 0;          /* victory conditions */
 int vcond_count = 0;
+Scen_Message *sMessages = NULL;	/* messages to show during the scenario */
+int sMessage_count = 0;		/* and their number */
 static int *casualties;	/* sum of casualties grouped by unit class and player */
 
 /*
@@ -156,6 +158,35 @@ static int subcond_check( VSubCond *cond )
             if ( count == cond->count )
                 return 1;
             return 0;
+        case VSUBCOND_UNITS_ESCAPED:
+			/* check all tagged units of player (or ally) whether they are 
+			* on a map tile marked as escape_zone */
+			list_reset( units );
+			count = 0;
+			while ( ( unit = list_next( units ) ) ) {
+				if ( !player_is_ally( cond->player, unit->player ) )
+					continue; /* not our unit */
+				if ( unit->tag[0] == 0 || !STRCMP( unit->tag, cond->tag ) )
+					continue; /* not or differently tagged */
+				if (unit->killed)
+					continue; /* has already been handeled or lost */
+                if (map[unit->x][unit->y].escape_zone) {
+					/* kill (the only true escape) unit directly? */
+					if (cond->remove) {
+						/* XXX not sure if this is ok here,
+						 * better place would be engine.c:2866
+						 * when deselecting unit on right click
+						 * but maybe it is ok here */
+						 map_remove_unit(unit);
+						 unit->killed = 1;
+						 cond->count--; /* only works if there is ONE condition for escaping only! */
+					} else 
+						count++; /* escaped but not removed directly */
+				}
+			}
+            if ( count == cond->count )
+                return 1;
+            return 0;
     }
     return 0;
 }
@@ -424,6 +455,14 @@ int scen_load( const char *fname )
         if ( map[x][y].nation )
             map[x][y].deploy_center = 1;
         map[x][y].obj = obj;
+        if (obj) {
+        	/* Convert to upper case */
+        	char *s = map[x][y].name;
+        	while (*s) {
+        		*s = toupper((unsigned char) *s);
+        		s++;
+        	}
+        }
     }
     /* victory conditions */
     scen_result[0] = 0;
@@ -509,6 +548,38 @@ int scen_load( const char *fname )
                         strcpy_lt( vconds[i].subconds_and[j].tag, str, 31 );
                         vconds[i].subconds_and[j].count = 0; /* units will be counted */
                     }
+                    else
+                    if ( STRCMP( pd_vsubcond->name, "units_escaped" ) ) {
+                        vconds[i].subconds_and[j].type = VSUBCOND_UNITS_ESCAPED;
+                        if ( !parser_get_value( pd_vsubcond, "player", &str, 0 ) ) goto parser_failure;
+                        vconds[i].subconds_and[j].player = player_get_by_id( str );
+                        if ( !parser_get_value( pd_vsubcond, "tag", &str, 0 ) ) goto parser_failure;
+                        strcpy_lt( vconds[i].subconds_and[j].tag, str, 31 );
+                        if ( parser_get_value( pd_vsubcond, "remove", &str, 0 ) && str[0] == '1') 
+							vconds[i].subconds_and[j].remove = 1;
+						else
+							vconds[i].subconds_and[j].remove = 0;
+                        vconds[i].subconds_and[j].coord_count = 0;
+						if ( parser_get_values( pd_vsubcond, "coordinates", &values ) && values->count>0 )
+						{
+							list_reset( values );
+							while ( ( lib = list_next( values ) ) ) {
+								get_coord( lib, &x, &y );
+								vconds[i].subconds_and[j].coords[vconds[i].subconds_and[j].coord_count][0]=x;
+								vconds[i].subconds_and[j].coords[vconds[i].subconds_and[j].coord_count][1]=y;
+								vconds[i].subconds_and[j].coord_count++;
+								/* map is already created so set tile as escape zone */
+								map[x][y].escape_zone = 1;
+								/* XXX hardcoded limit, see scenario.h */
+								if (vconds[i].subconds_and[j].coord_count == 100)
+									break;
+							}
+						}
+						if ( !parser_get_int( pd_vsubcond, "count", &vconds[i].subconds_and[j].count ) )
+							vconds[i].subconds_and[j].count = 0; /* units will be counted */
+						else
+							vconds[i].subconds_and[j].count *= -1; /* XXX add sign to prevent counting when reading unit flags */
+                    }
                     j++;
                 }
             }
@@ -648,16 +719,20 @@ int scen_load( const char *fname )
         if ( parser_get_value( sub, "tag", &str, 0 ) ) {
             strcpy_lt( unit_base.tag, str, 31 );
             /* check all subconds for UNITS_SAVED and increase the counter
-               if this unit is allied */
+               if this unit is allied; same for UNITS_ESCAPED */
             for ( i = 1; i < vcond_count; i++ ) {
                 for ( j = 0; j < vconds[i].sub_and_count; j++ )
-                    if ( vconds[i].subconds_and[j].type == VSUBCOND_UNITS_SAVED )
-                        if ( STRCMP( unit_base.tag, vconds[i].subconds_and[j].tag ) )
-                            vconds[i].subconds_and[j].count++;
+                    if ( vconds[i].subconds_and[j].type == VSUBCOND_UNITS_SAVED ||
+							vconds[i].subconds_and[j].type == VSUBCOND_UNITS_ESCAPED)
+						if( vconds[i].subconds_and[j].count>=0 ) /* negative means fixed predefined count */
+							if ( STRCMP( unit_base.tag, vconds[i].subconds_and[j].tag ) )
+								vconds[i].subconds_and[j].count++;
                 for ( j = 0; j < vconds[i].sub_or_count; j++ )
-                    if ( vconds[i].subconds_or[j].type == VSUBCOND_UNITS_SAVED )
-                        if ( STRCMP( unit_base.tag, vconds[i].subconds_or[j].tag ) )
-                            vconds[i].subconds_or[j].count++;
+                    if ( vconds[i].subconds_or[j].type == VSUBCOND_UNITS_SAVED ||
+							vconds[i].subconds_or[j].type == VSUBCOND_UNITS_ESCAPED)
+						if( vconds[i].subconds_or[j].count>=0 ) /* negative means fixed predefined count */
+							if ( STRCMP( unit_base.tag, vconds[i].subconds_or[j].tag ) )
+								vconds[i].subconds_or[j].count++;
             }
         }
         /* actual unit */
@@ -685,6 +760,13 @@ int scen_load( const char *fname )
 	    unit_ref++;
 	}
     }
+    /* check if any escape condition has negative count
+     * -> fixed number of units to be saved: remove sign */
+	for ( i = 1; i < vcond_count; i++ )
+		for ( j = 0; j < vconds[i].sub_and_count; j++ )
+			if ( vconds[i].subconds_and[j].type == VSUBCOND_UNITS_ESCAPED )
+				if( vconds[i].subconds_and[j].count < 0)
+					vconds[i].subconds_and[j].count *= -1;
     /* load deployment hexes */
     if ( parser_get_entries( pd, "deployfields", &entries ) ) {
         list_reset( entries );
@@ -710,6 +792,31 @@ int scen_load( const char *fname )
             }
         }
     }
+    /* load messages */
+    if ( parser_get_entries( pd, "messages", &entries ) ) {
+	/* count and alloc scenario messages */
+	list_reset( entries );
+	while ( ( list_next( entries ) ) )
+		sMessage_count++;
+	sMessages = calloc( sMessage_count, sizeof( Scen_Message ) );
+
+	/* load them now */
+	list_reset( entries ); i = 0;
+	while ( ( sub = list_next( entries ) ) ) {
+		if ( !parser_get_value( sub, "player", &str, 0 ) )
+			goto parser_failure;
+		sMessages[i].player = player_get_by_id( str );
+		if ( !sMessages[i].player )
+			goto parser_failure;
+		if( !parser_get_int( sub, "turn", &sMessages[i].turn ) )
+			goto parser_failure;
+		if( !parser_get_value( sub, "text", &str,0) )
+			goto parser_failure;
+		else
+			strcpy_lt( sMessages[i].message, str, 128 );
+		i++;
+	}
+    }
     parser_free( &pd );
 
     casualties = calloc( scen_info->player_count * unit_class_count, sizeof casualties[0] );
@@ -883,6 +990,15 @@ void scen_delete()
         free( vconds ); vconds = 0;
         vcond_count = 0;
     }
+    if( sMessages ) {
+/*        for ( i = 0; i < sMessage_count; i++ ) {
+		free( sMessages[i].message );
+		free( sMessages[i].player );
+	}
+*/	free( sMessages );
+	sMessages = NULL;
+	sMessage_count = 0;
+    }
     if ( units ) {
         list_delete( units );
         units = 0;
@@ -940,8 +1056,9 @@ void scen_prep_unit( Unit *unit, int type )
             unit->cur_mov = unit->cur_fuel;
     unit_unmount( unit );
     unit->cur_atk_count = unit->sel_prop->atk_count;
-    /* if unit is preparded normally check entrenchment */
-    if ( type == SCEN_PREP_UNIT_NORMAL && !(unit->sel_prop->flags & FLYING) ) {
+    /* if unit is prepared normally check entrenchment */
+    if ( type == SCEN_PREP_UNIT_NORMAL && !(unit->sel_prop->flags & FLYING)
+		    	    	    && !(unit->sel_prop->flags & SWIMMING)) {
         min_entr = map_tile( unit->x, unit->y )->terrain->min_entr;
         max_entr = map_tile( unit->x,unit->y )->terrain->max_entr;
         if ( unit->entr < min_entr )
